@@ -28,7 +28,6 @@
 #include <string.h>
 #include <gnome.h>
 #include <glade/glade.h>
-#include <bonobo.h>
 #include <gconf/gconf.h>
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
@@ -109,15 +108,39 @@ is_nautilus_running (void)
 	return running;
 }
 
+static gboolean
+gnome_cc_save_yourself (GnomeClient *client, gint phase, GnomeSaveStyle save_style,
+			gboolean shutdown, GnomeInteractStyle interact_style,
+			gboolean fast, gchar *argv0)
+{
+	gchar *argv[3];
+	gint argc;
+
+	argv[0] = argv0;
+	argv[1] = "--use-shell";
+	argc = 2;
+	gnome_client_set_clone_command (client, argc, argv);
+	gnome_client_set_restart_command (client, argc, argv);
+
+	return TRUE;
+}
+
+static void
+gnome_cc_die (GnomeClient *client, gpointer data)
+{
+	gtk_main_quit ();
+}
+
 int
 main (int argc, char **argv) 
 {
 	CappletDirEntry *entry;
 	CappletDir *dir;
+	GnomeClient *client;
 
-        bindtextdomain (PACKAGE, GNOMELOCALEDIR);
-	bind_textdomain_codeset (PACKAGE, "UTF-8");
-        textdomain (PACKAGE);
+        bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+        textdomain (GETTEXT_PACKAGE);
 
 	gnome_program_init ("control-center", VERSION, LIBGNOMEUI_MODULE,
 			    argc, argv,
@@ -137,6 +160,12 @@ main (int argc, char **argv)
 		return -1;
 	capplet_dir_entry_activate (entry, NULL);
 
+	client = gnome_master_client ();
+	g_signal_connect (G_OBJECT (client), "save_yourself",
+			  G_CALLBACK (gnome_cc_save_yourself), argv[0]);
+	g_signal_connect (G_OBJECT (client), "die",
+			  G_CALLBACK (gnome_cc_die), NULL);
+
 	gtk_main ();
 
 	return 0;
